"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cluster_1 = __importDefault(require("cluster"));
const httpReverseProxy_1 = require("../lib/httpReverseProxy");
const simpleHttpServer_1 = require("./simpleHttpServer");
const statistics_1 = require("../lib/statistics");
const statisticsServer_1 = require("../lib/statisticsServer");
const logger_1 = require("../lib/logger");
const stats = new statistics_1.Statistics();
let logger;
if (cluster_1.default.isMaster) {
    const statisticsServerOptions = {
        stats: stats,
        htmlFilename: './public/statisticsAndLoggingPage.html'
    };
    const server1 = new simpleHttpServer_1.SimpleHttpServer(1, 8001);
    const server2 = new simpleHttpServer_1.SimpleHttpServer(2, 8002);
    const statisticsServer = new statisticsServer_1.StatisticsServer(statisticsServerOptions);
    logger = new logger_1.Logger({
        port: 3002,
        logLevel: 10
    });
    logger.warn(null, `ClusteredProxy:
    Make sure you have:
      server1.qzqzqz.com  127.0.0.1
      server2.qzqzqz.com  127.0.0.1
    in your hosts file. See the Readme for details.

    Statistics and logs can be viewed from http://localhost:3001

    If you get a 404 Not Found for the statistics page, 
    exit the server and run it from the root of the project.
    Or run 'npm run clusteredExample' from the root of the project
  `);
    server1.start();
    server2.start();
}
else {
    logger = new logger_1.Logger();
}
const proxy = new httpReverseProxy_1.HttpReverseProxy({ clustered: true, stats: stats, log: logger });
proxy.addRoute('http://server1.qzqzqz.com', 'localhost:8001');
proxy.addRoute('http://server2.qzqzqz.com', 'localhost:8002');
logger.info(null, 'Proxy server started');
//# sourceMappingURL=clusteredProxy.js.map