"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const httpReverseProxy_1 = require("../lib/httpReverseProxy");
const simpleHttpServer_1 = require("./simpleHttpServer");
const letsEncryptUsingAcmeClient_1 = require("../lib/letsEncrypt/letsEncryptUsingAcmeClient");
const statistics_1 = require("../lib/statistics");
const statisticsServer_1 = require("../lib/statisticsServer");
const logger_1 = require("../lib/logger");
const hostname = '<Your Host Name>'; // replace this with your actual host name
const stats = new statistics_1.Statistics();
const logger = new logger_1.Logger({
    port: 3002,
    logLevel: 10
});
const statisticsServerOptions = {
    stats: stats,
    htmlFilename: './public/statisticsPage.html'
};
const letsEncryptServerOptions = {
    noVerify: true
};
const httpReverseProxyOptions = {
    letsEncryptOptions: letsEncryptServerOptions,
    httpsOptions: {
        port: 443,
        certificates: {
            certificateStoreRoot: './certificates'
        },
    },
    stats: stats,
    log: logger,
};
const routingOptions = {
    https: {
        redirectToHttps: true,
        letsEncrypt: {
            email: 'myname@mydomain.com',
            production: false,
        }
    }
};
const server1 = new simpleHttpServer_1.SimpleHttpServer(1, 8001);
const server2 = new simpleHttpServer_1.SimpleHttpServer(2, 8002);
const statisticsServer = new statisticsServer_1.StatisticsServer(statisticsServerOptions);
logger.warn(null, `LetsEncryptProxy:
    Make sure you have a valid, DNS registered host name.
    Before this example is run replace '<Your Host Name>' with
    the actual registered host name.

    If you are testing on a local network your router may not allow
    you to access a website that refers to the internet address of your router. 
    If you cannot retrieve the page try using your phone with the wi-fi turned off.

    When routingOptions.https.letsEncrypt.production is 'false'
    certificates for this example are do not have a valid certificate authority.
    The browser will warn of this when connecting and
    the output log will warn of client errors.
    See the Readme for more information.

    Once a certificate is issued it must be deleted from the certificates folder
    to force the next execution to request a new certificate.

    After testing with staging certificates (production === false)
    change the routingOptions.https.letsEncrypt.production to 'true'
    and delete the existing certificate to receive a production 
    certificate (backed by a certificate authority).

    Statistics can be viewed from http://localhost:3001

    If you get a 404 Not Found for the statistics page, 
    exit the server and run it from the root of the project.
    Or run 'npm run letsEncryptExample' from the root of the project
  `);
// @ts-ignore
if (hostname === '<Your Host Name>') {
    logger.error({ hostname: hostname }, `hostname in 'src/examples/letsEncryptProxy.ts' must be set to your registered host name`);
    process.exit(0);
}
server1.start();
server2.start();
const proxy = new httpReverseProxy_1.HttpReverseProxy(httpReverseProxyOptions, letsEncryptUsingAcmeClient_1.LetsEncryptUsingAcmeClient);
proxy.addRoute(hostname, 'localhost:8001', routingOptions);
proxy.addRoute(hostname, 'localhost:8002', routingOptions); // round robin between servers
logger.info({ hostname: hostname }, 'Https Lets Encrypt Proxy started');
//# sourceMappingURL=letsEncryptProxy.js.map