"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const httpReverseProxy_1 = require("../lib/httpReverseProxy");
const simpleHttpServer_1 = require("./simpleHttpServer");
const letsEncryptUsingSelfSigned_1 = require("../lib/letsEncrypt/letsEncryptUsingSelfSigned");
const statistics_1 = require("../lib/statistics");
const statisticsServer_1 = require("../lib/statisticsServer");
const logger_1 = require("../lib/logger");
const stats = new statistics_1.Statistics();
const logger = new logger_1.Logger({
    port: 3002,
    logLevel: 10
});
const statisticsServerOptions = {
    stats: stats,
    htmlFilename: './public/statisticsPage.html'
};
const letsEncryptServerOptions = {
    organizationName: 'Self testing',
    country: 'US',
    state: 'Georgia',
    locality: 'Roswell'
};
const httpReverseProxyOptions = {
    letsEncryptOptions: letsEncryptServerOptions,
    httpsOptions: {
        port: 443,
        certificates: {
            certificateStoreRoot: './certificates'
        },
    },
    stats: stats,
    log: logger,
};
const routingOptions = {
    https: {
        redirectToHttps: true,
        letsEncrypt: {
            email: 'myname@mydomain.com',
            production: false,
        }
    }
};
const server1 = new simpleHttpServer_1.SimpleHttpServer(1, 8001);
const server2 = new simpleHttpServer_1.SimpleHttpServer(2, 8002);
const statisticsServer = new statisticsServer_1.StatisticsServer(statisticsServerOptions);
logger.warn(null, `SimpleHttpsProxy:
    Make sure you have:
      server1.qzqzqz.com  127.0.0.1
      server2.qzqzqz.com  127.0.0.1
    in your hosts file. See the Readme for details.

    Certificates for this example are self-signed.
    The browser will warn of this when connected and
    the output log will warn of client errors.
    See the Readme for more information.

    Statistics can be viewed from http://localhost:3001

    If you get a 404 Not Found for the statistics page, 
    exit the server and run it from the root of the project.
    Or run 'npm run httpsExample' from the root of the project
  `);
server1.start();
server2.start();
const proxy = new httpReverseProxy_1.HttpReverseProxy(httpReverseProxyOptions, letsEncryptUsingSelfSigned_1.LetsEncryptUsingSelfSigned);
proxy.addRoute('https://server1.qzqzqz.com', 'localhost:8001', routingOptions);
proxy.addRoute('https://server2.qzqzqz.com', 'localhost:8002', routingOptions);
logger.info(null, 'Https Reverse Proxy server started');
//# sourceMappingURL=simpleHttpsProxy.js.map