import { Logger } from "../logger";
import { Statistics } from "../statistics";
export interface BaseDNSUpdateOptions {
    dnsNameServer?: string;
    dnsServerAttempts?: number;
    dnsServerDelay?: number;
    stats?: Statistics;
    log?: Logger;
}
/**
 * This is the base class for the DNS update.
 * Specific implementations extend this class to handle
 * the interaction with a particular DNS server
 */
export declare abstract class BaseDNSUpdate {
    protected dnsNameServer?: string;
    protected dnsServerAttempts: number;
    protected dnsServerdelay: number;
    protected stats: Statistics;
    protected log: Logger;
    constructor(options: BaseDNSUpdateOptions);
    /**
     * Implement these two methods in inherited class
     */
    abstract addAcmeChallengeToDNS(domain: string, challenge: string): Promise<boolean>;
    abstract removeAcmeChallengeFromDNS(domain: string): Promise<boolean>;
    /**
     * Add a DNS challenge with verification via DNS server
     */
    addDNSChallenge: (domain: string, challenge: string) => Promise<boolean>;
    /**
     * Remove the DNS challenge via the implementation
     */
    removeDNSChallenge: (domain: string) => Promise<boolean>;
    /**
    * Helper method to wait for the DNS servers to update
    */
    private waitForNameServerToUpdate;
}
