import { Logger } from '../logger';
import { BaseDNSUpdate, BaseDNSUpdateOptions } from './dnsUpdate';
interface DNSEntry {
    type: string;
    data: string;
    name: string;
    ttl: number;
}
/**
 * GoDaddy requires an APIKey and secret
 * both of which are available from their developer site
 */
export interface GoDaddyDNSUpdateOptions extends BaseDNSUpdateOptions {
    APIKey: string;
    secret: string;
}
/**
 * This method overrides the empty implmentation in the base class
 */
export declare class GoDaddyDNSUpdate extends BaseDNSUpdate {
    private apiKey;
    private secret;
    protected log: Logger;
    constructor(options: GoDaddyDNSUpdateOptions);
    /**
     * GoDaddy requires us to read all of the TXT records,
     * add our new record, and write back all of the TXT records
     */
    addAcmeChallengeToDNS: (domain: string, challenge: string) => Promise<boolean>;
    /**
     * Again we must read all of the TXT records,
     * remove the challenge record, and write the rest back
     */
    removeAcmeChallengeFromDNS: (domain: string) => Promise<boolean>;
    /**
     * This is a helper function to read records from the GoDaddy DNS
     */
    protected getRecordsOfType: (domain: string, type: string) => Promise<Error | DNSEntry[]>;
    protected updateRecordsOfType: (domain: string, type: string, records: DNSEntry[]) => Promise<boolean>;
    private buildGoDaddyDomainURL;
}
export {};
