/**
 * This is the AcmeClient (https://github.com/publishlab/node-acme-client) implemtation of the Let's Encrypt client
*/
import acmeClient from 'acme-client';
import { BaseLetsEncryptClient, BaseLetsEncryptOptions } from './letsEncrypt';
/**
 *  LetsEncryptServerOptions inherits from BaseLetsEncryptOptions
 *
 *  noVerify: optional switch to turn off the internal verification of the token/key with the internal server
 *      This is to avoid the problem for routers trying to twart the DNS-redis hack
 */
export interface LetsEncryptClientOptions extends BaseLetsEncryptOptions {
    noVerify?: boolean;
}
/**
 * THe implementation of the Let's Encrypt interface using acme-client
 */
export declare class LetsEncryptUsingAcmeClient extends BaseLetsEncryptClient {
    protected noVerify: boolean;
    constructor(options: LetsEncryptClientOptions);
    /**
     * This method overrides the empty method in the base class
     */
    protected getNewCertificate: (hostname: string, production: boolean, email: string) => Promise<boolean>;
    /**
     * Helper method to create the challenge response
     */
    protected createChallenge: (challenge: acmeClient.Challenge, host: string, keyAuthorization: string) => Promise<boolean>;
    /**
     * Remove the challenge response
     */
    protected destroyChallenge: (challenge: acmeClient.Challenge, host: string) => Promise<boolean>;
}
