/// <reference types="node" />
import http from 'http';
import WebSocket from 'ws';
import { ClusterMessage } from './httpReverseProxy';
export interface LoggingMessage extends ClusterMessage {
    workerId: number;
    type: string;
    data: {};
    message: string;
}
export declare const logLevels: {
    level: number;
    type: string;
}[];
/**
 * Configuration options for the http server started by
 * the logging server
 */
export interface LoggingServerOptions {
    host?: string;
    port?: number;
    htmlFilename?: string;
    logLevel?: number;
}
/**
 * Class to handle the individual WebSocket connections
 */
declare class WebSocketClient {
    protected logLevel: number;
    ws: WebSocket;
    open: () => void;
    close: () => void;
    constructor(logLevel: number, ws: WebSocket);
    sendLogMessage(level: number, data: {}, message: string): void;
}
export declare class Logger {
    protected logLevel: number;
    protected host: string;
    protected htmlFilename: string;
    protected port: number;
    protected httpServer: http.Server;
    protected websocketServer: WebSocket.Server;
    protected clients: WebSocketClient[];
    protected workerId: number;
    constructor(options?: LoggingServerOptions);
    /**
     * Start the Logging http server
     */
    private createHttpServer;
    /**
     * Create the websocket server
     */
    private createWebsocketServer;
    private log;
    debug(data: {} | null, message: string): void;
    trace(data: {} | null, message: string): void;
    info(data: {} | null, message: string): void;
    warn(data: {} | null, message: string): void;
    error(data: {} | null, message: string): void;
    fatal(data: {} | null, message: string): void;
    processMessage: (message: LoggingMessage) => void;
    close: () => void;
}
export {};
