import { ProxyUrl } from "./util";
import { Logger } from "./logger";
import { RouteRegistrationOptions } from "./httpRouter";
import { Statistics } from "./statistics";
/**
 * The base Route class.
 *
 * A Route holds an inbound path (the url part of the addRoute from)
 * and a list of targets
 */
export declare class Route {
    path: string;
    protected roundRobin: number;
    targets: ProxyUrl[];
    protected log: Logger;
    protected stats: Statistics;
    /**
     * At a minimum a Route has the inbound path '/'
     */
    constructor(path: string, log?: Logger, stats?: Statistics);
    /**
     * For routes with multiple targets we return targets ina round robin manner
     */
    nextTarget: () => ProxyUrl;
    /**
     * Helper method to determine an empty target table
     */
    noTargets: () => boolean;
    /**
     * Add target(s) to the route
     */
    addTargets: (targets: string | ProxyUrl | (string | ProxyUrl)[], options: RouteRegistrationOptions) => Route;
    /**
     * Remove target(s) from the Route
     */
    removeTargets: (targets?: string | ProxyUrl | (string | ProxyUrl)[]) => Route;
    /**
     * Clear all of the targets on the Route
     */
    removeAllTargets: () => this;
}
