"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cluster_1 = __importDefault(require("cluster"));
class Statistics {
    constructor() {
        this.updateCount = (name, count, workerId = this.workerId) => {
            if (!name) {
                return;
            }
            if (cluster_1.default.isWorker) {
                process.send({
                    messageType: 'statistics',
                    action: 'updateCount',
                    workerId: this.workerId,
                    name: name,
                    count: count
                });
            }
            else {
                const entry = this.statTable[`${workerId}:${name}`];
                if (!entry) {
                    this.statTable[`${workerId}:${name}`] = count;
                }
                else {
                    this.statTable[`${workerId}:${name}`] += count;
                }
            }
        };
        this.getTable = () => {
            return { ...this.statTable };
        };
        this.getCount = (name, workerId = this.workerId) => {
            if (name && this.statTable[`${workerId}:${name}`]) {
                return this.statTable[`${workerId}:${name}`];
            }
            return 0;
        };
        this.clearCounts = () => {
            for (const name in this.statTable) {
                this.statTable[name] = 0;
            }
        };
        this.clearCount = (name, workerId = this.workerId) => {
            if (name && this.statTable[`${workerId}:${name}`]) {
                this.statTable[`${workerId}:${name}`] = 0;
            }
        };
        this.processMessage = (message) => {
            switch (message.action) {
                case 'updateCount':
                    if (cluster_1.default.isMaster) {
                        this.updateCount(message.name, message.count, message.workerId);
                    }
                    break;
                default:
                    break;
            }
        };
        this.statTable = {};
        if (cluster_1.default.isWorker) {
            this.workerId = cluster_1.default.worker.id;
        }
        else {
            this.workerId = 0;
        }
    }
}
exports.Statistics = Statistics;
//# sourceMappingURL=statistics.js.map