import { Statistics } from './statistics';
import { Logger } from './logger';
/**
 * Configuration options for the http server started by
 * the Statistics server
 */
export interface StatisticsServerHttpOptions {
    host?: string;
    port: number;
}
/**
 * Configuration options for the Websocket interface to the Statistics server
 */
export interface StatisticsServerWebsocketOptions {
    updateInterval?: number;
    filter?: string[];
}
/**
 * Configuration options for the statistics server
 */
export interface StatisticsServerOptions {
    stats: Statistics;
    noStart?: boolean;
    htmlFilename?: string;
    http?: StatisticsServerHttpOptions;
    websocket?: StatisticsServerWebsocketOptions;
    log?: Logger;
}
/**
 * The statistics server is started with an instance of the Statistics class.
 * This is most often a singleton class created in the root of the proxy startup
 * code. Statistics entries are updated in the Statistics object.
 * The Statistics server sends to current state of the Statistics instance to
 * out to the clients via a websocket interface
 */
export declare class StatisticsServer {
    private host;
    private port;
    private htmlFilename;
    private updateInterval;
    private filter;
    private httpServer;
    private websocketServer;
    private stats;
    private log;
    constructor(options: StatisticsServerOptions);
    /**
     * Extract the option information from the statistics options
     */
    private setOptions;
    /**
     * The statistics server can be created and started in a single step or the
     * server can be started later in the overall startup process with additional/
     * changed options
     */
    start: (options?: StatisticsServerOptions) => void;
    /**
     * Stop the statistics server. It can be restarted again.
     */
    stop: () => void;
    /**
     * Start the Statistics server http server
     */
    private createHttpServer;
    /**
     * Respond to the connections to websocket server
     */
    private createWebsocketServer;
}
