"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const url_1 = require("url");
exports.makeUrl = (url) => {
    if ("object" === typeof url) {
        url = Object.assign({}, url);
    }
    else {
        if ('string' === typeof url) {
            url = url_1.parse(exports.prependHttpIfRequired(url));
        }
    }
    if (url && url.protocol && url.host) {
        url.host = url.host.toLowerCase();
        if (!url.pathname) {
            url.pathname = '/';
        }
        url.pathname = url.pathname.toLowerCase();
        return url;
    }
    return null;
};
exports.prependHttpIfRequired = (link) => {
    if (link.search(/^http[s]?\:\/\//i) === -1) {
        link = 'http://' + link;
    }
    return link;
};
exports.startsWith = (input, str) => {
    return input.slice(0, str.length) === str &&
        (input.length === str.length || input[str.length] === '/');
};
exports.respondNotFound = (req, res) => {
    res.statusCode = 404;
    res.write('HTTP/1.1 404 Not Found');
    res.end();
};
const ONE_DAY = 24 * 60 * 60 * 1000;
/**
 * The timeout in node is only good for about 24 days.
 *
 * Certificates routinely expire over the span of months.
 *
 * The long timeout fires internally once a day until the last
 * day and then fires the external callback when the time has finally
 * expired
 */
class LongTimeout {
    constructor(callback, expiration, ...callbackArgs) {
        this.timerFired = () => {
            this.clearTimer();
            if (this.expiration <= Date.now()) {
                this.callback(...this.callbackArgs);
            }
            else {
                this.setTimer();
            }
        };
        this.setTimer = () => {
            this.clearTimer();
            const interval = this.expiration - Date.now();
            this.timer = setTimeout(this.timerFired, interval >= ONE_DAY ? ONE_DAY : interval);
        };
        this.clearTimer = () => {
            if (this.timer) {
                clearTimeout(this.timer);
                this.timer = null;
            }
        };
        this.expiration = (expiration instanceof Date)
            ? expiration.valueOf()
            : Date.now() + expiration;
        this.callbackArgs = callbackArgs;
        this.callback = callback;
        this.setTimer();
    }
}
exports.LongTimeout = LongTimeout;
exports.setLongTimeout = (callback, expiration) => {
    return new LongTimeout(callback, expiration);
};
exports.clearLongTimeout = (timeout) => {
    timeout && timeout.clearTimer();
};
//# sourceMappingURL=util.js.map