"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../index");
const statistics = new index_1.Statistics();
const statisticsOptions = {
    stats: statistics,
    http: {
        port: 3001
    },
    websocket: {
        updateInterval: 1000,
    }
};
const letsEncryptSelfSignedOptions = {
    organizationName: 'Self Signed Testing',
    country: 'US',
    state: 'Georgia',
    locality: 'Roswell',
};
const httpProxyOptions = {
    proxyOptions: {
        xfwd: false,
    },
    httpsOptions: {
        certificates: new index_1.Certificates({ certificateStoreRoot: './certificates' }),
    },
    letsEncryptOptions: letsEncryptSelfSignedOptions,
    log: new index_1.Logger({
        port: 3002,
        logLevel: 40
    }),
    stats: statistics
};
const registrationLetsEncryptOptions = {
    email: "myname@mydomain.com",
    production: false,
    forceRenew: true
};
const httpsRouteRegistrationOptions = {
    secureOutbound: false,
    useTargetHostHeader: true,
    https: {
        redirectToHttps: true,
        letsEncrypt: registrationLetsEncryptOptions
    }
};
let statisticsServer = null;
let proxy = null;
exports.startProxy = () => {
    statisticsServer = new index_1.StatisticsServer(statisticsOptions);
    proxy = new index_1.HttpReverseProxy(httpProxyOptions, index_1.LetsEncryptUsingSelfSigned);
    proxy.addRoute('server9.qzqzqz.com', 'localhost:3001');
    proxy.addRoute('server1.qzqzqz.com', 'localhost:9001');
    proxy.addRoute('server2.qzqzqz.com', 'localhost:9002');
    proxy.addRoute('server3.qzqzqz.com', 'localhost:9003');
    proxy.addRoute('server1.qzqzqz.com/testing', 'localhost:9001');
    proxy.addRoute('server2.qzqzqz.com/testing', 'localhost:9002');
    proxy.addRoute('server3.qzqzqz.com/testing', 'localhost:9003');
    proxy.addRoute('server1.qzqzqz.com/test', '127.0.0.1:9001/test');
    proxy.addRoute('server2.qzqzqz.com/test', '127.0.0.1:9002/test');
    proxy.addRoute('server3.qzqzqz.com/test', '127.0.0.1:9003/test');
    proxy.addRoute('server4.qzqzqz.com', 'server3.qzqzqz.com', { useTargetHostHeader: true });
    proxy.addRoute('server5.qzqzqz.com', 'server4.qzqzqz.com', { useTargetHostHeader: true });
    proxy.addRoute('server6.qzqzqz.com', 'server5.qzqzqz.com', { useTargetHostHeader: true });
    proxy.addRoute('server7.qzqzqz.com', 'server6.qzqzqz.com', httpsRouteRegistrationOptions);
};
exports.stopProxy = () => {
    proxy && proxy.close();
    statisticsServer && statisticsServer.stop();
    httpProxyOptions.log && httpProxyOptions.log.close();
};
//# sourceMappingURL=blackboxProxy.js.map