"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const blackboxProxy_1 = require("./blackboxProxy");
const blackboxServers_1 = require("./blackboxServers");
const blackboxClients_1 = require("./blackboxClients");
const runAll = async (httpIterations, websocketIterations, stringSize = 500) => {
    blackboxServers_1.startServers();
    blackboxProxy_1.startProxy();
    const status = await blackboxClients_1.sendRandoms(stringSize);
    if (status !== 'OK') {
        blackboxProxy_1.stopProxy();
        blackboxServers_1.stopServers();
        return false;
    }
    await Promise.all([
        blackboxClients_1.runHttpTests(httpIterations),
        blackboxClients_1.runWebsocketTests(websocketIterations),
    ]);
    // Wait for the Proxy server statistics to propagate
    await new Promise((resolve) => {
        setTimeout(() => {
            resolve();
        }, 2000);
    });
    blackboxProxy_1.stopProxy();
    blackboxServers_1.stopServers();
    return true;
};
if (process.argv.length > 2) {
    const iterations1 = process.argv.length > 3 ? Number(process.argv[3]) : 500;
    const iterations2 = process.argv.length > 4 ? Number(process.argv[4]) : 0;
    switch (process.argv[2]) {
        case 'http':
            console.log('Starting Http clients');
            blackboxClients_1.sendRandoms(100);
            blackboxClients_1.runHttpTests(iterations1);
            break;
        case 'ws':
            console.log('Starting Websocket clients');
            blackboxClients_1.sendRandoms(100);
            blackboxClients_1.runWebsocketTests(iterations1);
            break;
        case 'servers':
            console.log('Starting servers');
            blackboxServers_1.startServers();
            break;
        case 'proxy':
            console.log('Starting proxy');
            blackboxProxy_1.startProxy();
            break;
        case 'all':
            console.log('Starting all components');
            runAll(iterations1, iterations2);
            break;
        default:
            console.log('usage: node blackboxTests.js all [httpIterations [websocketIterations]] | http [iterations] | web [iterations] | servers  | proxy');
            break;
    }
}
else {
    console.log('usage: node blackboxTests.js all [httpIterations [websocketIterations]] | http [iterations] | web [iterations] | servers  | proxy');
}
//# sourceMappingURL=blackboxTests.js.map